Contributors to Askbot Project — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# Contributors to Askbot Project

This is the list of contributors to the code of Askbot project. The list is probably incomplete, apologies for any omissions. Thanks for all your help

## Programming, bug fixes and documentation

- Mike Chen & Sailing Cai - original authors of CNPROG forum

- Evgeny Fadeev - founder of askbot

- Adolfo Fitoria

- Tomasz Zielinski

- Sayan Chowdhury

- Andy Knotts

- Benoit Lavine (with Windriver Software, Inc.)

- Jeff Madynski

- Jishnu

- Hrishi

- Andrei Mamoutkine

- Daniel Mican

- Dejan Noveski

- Vasil Vangelovski

- Ramiro Morales (with Machinalis)

- Vladimir Bokov

- NoahY

- Gael Pasgrimaud (bearstech)

- Arun SAG

- Rag Sagar

- Alex Robbins

- Tomasz Szynalski

- Raghu Udiyar

- Alexander Werner

- Rosandra Cuello Suñol

- hjwp

- Jacob Oscarson

- Radim Řehůřek

- monkut

- Jim Tittsler

- Silvio Heuberger

- Alexandros

- Paul Backhouse

- jtrain

- Niki Rocco

- Tyler Mandry

- Jorge López Pérez

- Zafer Cakmak

- Kevin Porterfield

- Robert Martin

- Director

- Stéphane Klein

- Andrew Chen

- Benjamin Abel

- Pami Ketolainen

- Hamdi

- michas2

- Francis Devereux

- Andrew Chen

- Egil Moeller

- Jerry Zhenlei Cai

- Dmitry

- Ruslan Keba

- Vanessa Hänni

- Vadim Sikora

- Zhe Li

- Sebastian Wagner

- martin-bts

- Ralf Bueker

## Translations

Thanks for the help to all translators. If you believe you were incorrectly missed out of this list, please let us know at support@askbot.com.

- Mike Chen, Sailing Cai, suyu8776 - Chinese

- Bruno Sarlo, Adolfo Fitoria, Francisco Espinoza - Spanish

- Evgeny Kalinin, Andrey Komrachkov - Russian

- Evgeny Fadeev - English

- Oktay Yildiz, Onur Mat, Cemre - Turkish

- Jérôme Blondon (bearstech) - French

- Pekka Gaiser, Edur - German

- Pekka Järvinen - Finnish

- Adi Robian - Romanian

- Stefano Mancini, Dario Ghilardi, Federico Poloni, Luca Ferroni - Italian

- Cong It, Nguyen Long, ppranhh - Vietnamese

- Jordi Bofill - Catalan

- Vašek Chalupníček - Chech

- Dario Kolak - Croatian

.